# -*- coding: utf-8 -*-
from djangorestframework_camel_case2.settings import api_settings
from djangorestframework_camel_case2.util import camelize


class CamelCaseJSONRenderer(api_settings.RENDERER_CLASS):
    def render(self, data, *args, **kwargs):
        return super(CamelCaseJSONRenderer, self).render(camelize(data), *args,
                                                         **kwargs)



#!/usr/bin/env python
# -*- coding: utf-8 -*-

from setuptools import setup, find_packages

import djangorestframework_camel_case2

with open('README.md', 'r') as fh:
    readme = fh.read()

with open('CHANGELOG.md', 'r') as fh:
    changelog = fh.read()

setup(
    name='djangorestframework-camel-case2',
    version=djangorestframework_camel_case2.__version__,
    url='https://github.com/fadawar/djangorestframework-camel-case2',
    description='Camel case JSON support for Django REST framework',
    license='BSD',
    long_description=readme + '\n\n' + changelog,
    long_description_content_type='text/markdown',
    author='jozo',
    author_email='hi@jozo.io',
    packages=find_packages(exclude=['tests*']),
    include_package_data=True,
    keywords='djangorestframework_camel_case2',
    classifiers=[
        'Development Status :: 4 - Beta',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Natural Language :: English',
        "Programming Language :: Python :: 2",
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.3',
    ],
    test_suite='tests',
)



# -*- coding: utf-8 -*-

from django.conf import settings
from django.core.exceptions import ImproperlyConfigured

from rest_framework.settings import APISettings

USER_SETTINGS = getattr(settings, 'JSON_CAMEL_CASE', {})

DEFAULTS = {
    'RENDERER_CLASS': 'rest_framework.renderers.JSONRenderer',
    'PARSER_CLASS': 'rest_framework.parsers.JSONParser',

    'JSON_UNDERSCOREIZE': {
        'no_underscore_before_number': False,
    },
}

# List of settings that may be in string import notation.
IMPORT_STRINGS = (
    'RENDERER_CLASS',
    'PARSER_CLASS'
)

VALID_SETTINGS = {
    'RENDERER_CLASS': (
        'rest_framework.renderers.JSONRenderer',
        'rest_framework.renderers.UnicodeJSONRenderer',
    ),
    'PARSER_CLASS': (
        'rest_framework.parsers.JSONParser',
    )
}


def validate_settings(input_settings, valid_settings):
    for setting_name, valid_values in valid_settings.items():
        input_setting = input_settings.get(setting_name)
        if input_setting and input_setting not in valid_values:
            raise ImproperlyConfigured(setting_name)


validate_settings(USER_SETTINGS, VALID_SETTINGS)

api_settings = APISettings(USER_SETTINGS, DEFAULTS, IMPORT_STRINGS)
